<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:am="http://www.anchormodeling.com/model">
	<xsl:output method="text" version="1.0" encoding="iso-8859-1" indent="no"/>
	<xsl:key name="mnemonicToEntity" match="//*[@mnemonic]" use="@mnemonic"/>
	<xsl:template match="/am:model">
		<xsl:variable name="model">
			<xsl:choose>
				<xsl:when test="@name">
					<xsl:value-of select="@name"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>AnchorModel</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable> 
		<xsl:text>/* </xsl:text>
		<xsl:text>&#10; * Use the following command to create and SVG graph using Graphviz: </xsl:text>
		<xsl:text>&#10; * neato -Tsvg -Gstart=rand -o </xsl:text>
		<xsl:value-of select="$model"/>
		<xsl:text>.svg </xsl:text>
		<xsl:value-of select="$model"/>
		<xsl:text>.dot</xsl:text>
		<xsl:text>&#10; */</xsl:text>

		<!-- start the graph part -->
		
		<xsl:text>&#10;&#10;graph </xsl:text>
		<xsl:value-of select="$model"/>
		<xsl:text> {</xsl:text>
		<xsl:text>&#10;&#9;packmode="graph";&#10;&#9;smoothing="triangle";</xsl:text>
		<xsl:text>&#10;&#9;node [fontname="Helvetica",fontsize="14"];</xsl:text>

		<!-- process all knots -->

		<xsl:for-each select="am:knot">
			<xsl:text>&#10;&#9;&#9;// </xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>&#10;&#9;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text> [shape="rectangle",style="rounded",color="#ff6666",peripheries="1"];</xsl:text>
		</xsl:for-each>

		<!-- process the anchors -->

		<xsl:for-each select="am:anchor">
			<xsl:text>&#10;&#9;&#9;// </xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>&#10;&#9;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text> [shape="rectangle",regular,style="filled",color="#ff6666",peripheries="1"];</xsl:text>

			<!-- process the attributes belonging to the anchor in an inner loop -->

			<xsl:for-each select="am:attribute">
				<xsl:text>&#10;&#9;&#9;&#9;// </xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_</xsl:text>
				<xsl:value-of select="@name"/>
				<xsl:text>&#10;&#9;&#9;&#9;</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:choose>
					<xsl:when test="@historized = 'true'">
						<xsl:text> [shape="ellipse",color="#ff6666",peripheries="2"];</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text> [shape="ellipse",color="#ff6666",peripheries="1"];</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:for-each>

		<!-- process all ties -->

		<xsl:for-each select="am:tie">
			<xsl:text>&#10;&#9;&#9;// </xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>&#10;&#9;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:choose>
				<xsl:when test="@historized = 'true'">
					<xsl:text> [shape="diamond",style="filled",color="#c0c0c0",peripheries="2"];</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text> [shape="diamond",style="filled",color="#c0c0c0",peripheries="1"];</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>


		<!-- process the anchors -->

		<xsl:text>&#10;&#9;edge [dir="forward"];</xsl:text>
		<xsl:for-each select="am:anchor">
			<xsl:variable name="anchor" select="@mnemonic"/>
			<!-- process the attributes belonging to the anchor in an inner loop -->
			<xsl:for-each select="am:attribute">
				<xsl:variable name="attribute" select="@mnemonic"/>
				<xsl:text>&#10;&#9;&#9;</xsl:text>
				<xsl:value-of select="$attribute"/>
				<xsl:text> -- </xsl:text>
				<xsl:value-of select="$anchor"/>
				<xsl:text> [len="1.25"];</xsl:text>
				<xsl:for-each select="am:relation">
					<xsl:text>&#10;&#9;&#9;&#9;</xsl:text>
					<xsl:value-of select="$attribute"/>
					<xsl:text> -- </xsl:text>
					<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
					<xsl:text> [len="1"];</xsl:text>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:for-each>

		<!-- process all ties -->

		<xsl:text>&#10;&#9;edge [dir="forward"];</xsl:text>
		<xsl:for-each select="am:tie">
			<xsl:variable name="tie" select="@mnemonic"/>
			<xsl:for-each select="am:relation">
				<xsl:text>&#10;&#9;&#9;</xsl:text>
				<xsl:value-of select="$tie"/>
				<xsl:text> -- </xsl:text>
				<xsl:variable name="node" select="key('mnemonicToEntity', @reference)"/>
				<xsl:value-of select="$node/@mnemonic"/>
				<xsl:choose>
					<xsl:when test="$node[local-name() = 'knot']">
						<xsl:text> [len="1"</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text> [len="2"</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="@primary = 'true'">
						<xsl:text>,arrowtail="dot"</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>,arrowtail="odot"</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text>];</xsl:text>
			</xsl:for-each>
		</xsl:for-each>

		<xsl:text>&#10;}</xsl:text>
	</xsl:template>
</xsl:stylesheet>
