<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:am="http://www.anchormodeling.com/model">
	<xsl:output method="text" version="1.0" encoding="iso-8859-1" indent="no"/>
	<xsl:key name="mnemonicToEntity" match="//*[@mnemonic]" use="@mnemonic"/>
	<xsl:template match="/am:model">
		<xsl:variable name="metadata">
			<xsl:text>_metadata int not null</xsl:text>
		</xsl:variable>
		<xsl:variable name="globalHistorizationType" select="@historizationType"/>

		<!-- process all knots -->

		<xsl:for-each select="am:knot">
			<xsl:text>IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = '</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%U%')&#10;</xsl:text>
			<xsl:text>CREATE TABLE [</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] ( &#10;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_ID </xsl:text>
			<xsl:value-of select="@idType"/>
			<xsl:if test="@idGenerator = 'true'">
				<xsl:text> identity(1,1)</xsl:text>
			</xsl:if>
			<xsl:text> not null, &#10;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>&#32;</xsl:text>
			<xsl:value-of select="@valueType"/>
			<xsl:text> not null, &#10;&#9;</xsl:text>
			<xsl:value-of select="$metadata"/>
			<xsl:text>, &#10;&#9;PRIMARY KEY (</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_ID asc</xsl:text>
			<xsl:text>) &#10;);&#10;GO&#10;</xsl:text>
		</xsl:for-each>

		<!-- process the anchors -->

		<xsl:for-each select="am:anchor">
			<xsl:text>IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = '</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%U%')&#10;</xsl:text>
			<xsl:text>CREATE TABLE [</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] ( &#10;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_ID </xsl:text>
			<xsl:value-of select="@idType"/>
			<xsl:if test="not(@idGenerator = 'false')">
				<xsl:text> identity(1,1)</xsl:text>
			</xsl:if>
			<xsl:text> not null, &#10;&#9;</xsl:text>
			<xsl:value-of select="$metadata"/>
			<xsl:text>, &#10;&#9;PRIMARY KEY (</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_ID asc) &#10;);&#10;GO&#10;</xsl:text>

			<!-- process the attributes belonging to the anchor in an inner loop -->

			<xsl:for-each select="am:attribute">
				<xsl:text>IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = '</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_</xsl:text>
				<xsl:value-of select="@name"/>
				<xsl:text>' and type LIKE '%U%')&#10;</xsl:text>
				<xsl:text>CREATE TABLE [</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_</xsl:text>
				<xsl:value-of select="@name"/>
				<xsl:text>] ( &#10;&#9;</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID </xsl:text>
				<xsl:value-of select="parent::am:anchor/@idType"/>
				<xsl:text> not null, &#10;&#9;</xsl:text>
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', am:relation/@reference)">
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>_ID </xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@idType"/>
						<xsl:text> not null, &#10;&#9;</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@name"/>
						<xsl:text>&#32;</xsl:text>
						<xsl:value-of select="@valueType"/>
						<xsl:text> not null, &#10;&#9;</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="@historized = 'true'">
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate </xsl:text>
					<xsl:value-of select="$globalHistorizationType"/>
					<xsl:text> not null, &#10;&#9;</xsl:text>
				</xsl:if>
				<xsl:value-of select="$metadata"/>
				<xsl:text>, &#10;&#9;PRIMARY KEY (</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID asc</xsl:text>
				<xsl:if test="@historized = 'true'">
					<xsl:text>, </xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate desc</xsl:text>
				</xsl:if>
				<xsl:text>) &#10;);&#10;GO&#10;</xsl:text>
			</xsl:for-each>

			<!-- create the latest view -->

			<xsl:text>IF EXISTS (SELECT * FROM sys.objects WHERE name = 'l</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%V%')&#10;</xsl:text>
			<xsl:text>DROP VIEW [l</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>]; &#10;GO&#10;</xsl:text>
			<xsl:text>CREATE VIEW [l</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] AS &#10;SELECT &#10;&#9;[</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>].</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_ID</xsl:text>
			<xsl:if test="am:attribute">
				<xsl:text>, &#10;&#9;</xsl:text>
			</xsl:if>
			<xsl:for-each select="am:attribute">
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', am:relation/@reference)">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@name"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="@historized = 'true'">
					<xsl:text>, &#10;&#9;[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate</xsl:text>
				</xsl:if>
				<xsl:if test="not(position() = last())">
					<xsl:text>, &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#10;FROM &#10;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>&#32;[</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>]</xsl:text>
			<xsl:for-each select="am:attribute">
				<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_</xsl:text>
				<xsl:value-of select="@name"/>
				<xsl:text>&#32;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID = [</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID</xsl:text>
				<xsl:if test="@historized = 'true'">
					<xsl:text>&#10;AND &#10;&#9;[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate = (&#10;&#9;&#9;SELECT &#10;&#9;&#9;&#9;max(</xsl:text>
					<xsl:text>sub.</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate) &#10;&#9;&#9;FROM &#10;&#9;&#9;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@name"/>
					<xsl:text> sub &#10;&#9;&#9;WHERE &#10;&#9;&#9;&#9;sub.</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>_ID &#10;&#9;)</xsl:text>
				</xsl:if>
				<xsl:if test="am:relation">
					<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@name"/>
					<xsl:text>&#32;[</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_ID</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>;&#10;GO&#10;</xsl:text>

			<!-- create the point-in-time function -->

			<xsl:text>IF EXISTS (SELECT * FROM sys.objects WHERE name = 'p</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%F%')&#10;</xsl:text>
			<xsl:text>DROP FUNCTION [p</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>]; &#10;GO&#10;</xsl:text>
			<xsl:text>CREATE FUNCTION [p</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] (@timepoint </xsl:text>
			<xsl:value-of select="$globalHistorizationType"/>
			<xsl:text>) &#10;RETURNS TABLE RETURN &#10;SELECT &#10;&#9;[</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>].</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_ID</xsl:text>
			<xsl:if test="am:attribute">
				<xsl:text>, &#10;&#9;</xsl:text>
			</xsl:if>
			<xsl:for-each select="am:attribute">
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', am:relation/@reference)">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@name"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="@historized = 'true'">
					<xsl:text>, &#10;&#9;[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate</xsl:text>
				</xsl:if>
				<xsl:if test="not(position() = last())">
					<xsl:text>, &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#10;FROM &#10;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>&#32;[</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>]</xsl:text>
			<xsl:for-each select="am:attribute">
				<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_</xsl:text>
				<xsl:value-of select="@name"/>
				<xsl:text>&#32;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID = [</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID</xsl:text>
				<xsl:if test="@historized = 'true'">
					<xsl:text>&#10;AND &#10;&#9;[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate = (&#10;&#9;&#9;SELECT &#10;&#9;&#9;&#9;max(</xsl:text>
					<xsl:text>sub.</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate) &#10;&#9;&#9;FROM &#10;&#9;&#9;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@name"/>
					<xsl:text> sub &#10;&#9;&#9;WHERE &#10;&#9;&#9;&#9;sub.</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>_ID &#10;&#9;&#9;AND &#10;&#9;&#9;&#9;sub.</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate &lt;= @timepoint</xsl:text>
					<xsl:text>&#10;&#9;)</xsl:text>
				</xsl:if>
				<xsl:if test="am:relation">
					<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@name"/>
					<xsl:text>&#32;[</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_ID</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<!-- 
			<xsl:if test="am:attribute[@historized = 'true']">
				<xsl:text>&#10;WHERE &#10;&#9;</xsl:text>
			</xsl:if>
			<xsl:for-each select="am:attribute[@historized = 'true']">
				<xsl:choose>
					<xsl:when test="am:relation">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@name"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text> is not null</xsl:text>
				<xsl:if test="not(position() = last())">
					<xsl:text>&#10;OR &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			-->
			<xsl:text>;&#10;GO&#10;</xsl:text>

			<!-- create the difference function -->

			<xsl:text>IF EXISTS (SELECT * FROM sys.objects WHERE name = 'd</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%F%')&#10;</xsl:text>
			<xsl:text>DROP FUNCTION [d</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>]; &#10;GO&#10;</xsl:text>
			<xsl:text>CREATE FUNCTION [d</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] (@intervalStart </xsl:text>
			<xsl:value-of select="$globalHistorizationType"/>
			<xsl:text>, @intervalEnd </xsl:text>
			<xsl:value-of select="$globalHistorizationType"/>
			<xsl:text>) &#10;RETURNS TABLE RETURN &#10;SELECT &#10;&#9;</xsl:text>
			<xsl:choose>
				<xsl:when test="am:attribute[@historized = 'true']">
					<xsl:text>[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>]._inspectedDate, &#10;&#9;</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>NULL as _inspectedDate, &#10;&#9;</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>[</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>].</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_ID</xsl:text>
			<xsl:if test="am:attribute">
				<xsl:text>, &#10;&#9;</xsl:text>
			</xsl:if>
			<xsl:for-each select="am:attribute">
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', am:relation/@reference)">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@name"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="@historized = 'true'">
					<xsl:text>, &#10;&#9;[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate</xsl:text>
				</xsl:if>
				<xsl:if test="not(position() = last())">
					<xsl:text>, &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#10;FROM </xsl:text>
			<xsl:choose>
				<xsl:when test="am:attribute[@historized = 'true']">
					<xsl:text>(&#10;&#9;SELECT DISTINCT &#10;&#9;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_ID, &#10;&#9;&#9;_inspectedDate &#10;&#9;FROM (&#10;&#9;&#9;SELECT &#10;&#9;&#9;&#9;</xsl:text>
					<xsl:text>[s</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_ID, &#10;&#9;&#9;&#9;</xsl:text>
					<xsl:for-each select="am:attribute[@historized = 'true']">
						<xsl:text>[s</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_FromDate</xsl:text>
						<xsl:if test="not(position() = last())">
							<xsl:text>, &#10;&#9;&#9;&#9;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:text>&#10;&#9;&#9;FROM &#10;&#9;&#9;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@name"/>
					<xsl:text> [s</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>]</xsl:text>
					<xsl:for-each select="am:attribute[@historized = 'true']">
						<xsl:text>&#10;&#9;&#9;LEFT JOIN &#10;&#9;&#9;&#9;</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@name"/>
						<xsl:text> [s</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>]&#10;&#9;&#9;ON &#10;&#9;&#9;&#9;[s</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="parent::am:anchor/@mnemonic"/>
						<xsl:text>_ID = [s</xsl:text>
						<xsl:value-of select="parent::am:anchor/@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="parent::am:anchor/@mnemonic"/>
						<xsl:text>_ID</xsl:text>
						<xsl:text>&#10;&#9;&#9;AND &#10;&#9;&#9;&#9;[s</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_FromDate between @intervalStart and @intervalEnd</xsl:text>
					</xsl:for-each>
					<xsl:text>&#10;&#9;) piv &#10;&#9;UNPIVOT (&#10;&#9;&#9;_inspectedDate for _historizationColumn in (&#10;&#9;&#9;&#9;</xsl:text>
					<xsl:for-each select="am:attribute[@historized = 'true']">
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_FromDate</xsl:text>
						<xsl:if test="not(position() = last())">
							<xsl:text>, &#10;&#9;&#9;&#9;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:text>&#10;&#9;&#9;) &#10;&#9;) unpiv &#10;) </xsl:text>
					<xsl:value-of select="@mnemonic"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>&#10;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@name"/>
					<xsl:text>&#32;[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>]</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:for-each select="am:attribute">
				<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_</xsl:text>
				<xsl:value-of select="@name"/>
				<xsl:text>&#32;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID = [</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID</xsl:text>
				<xsl:if test="@historized = 'true'">
					<xsl:text>&#10;AND &#10;&#9;</xsl:text>
					<xsl:text>[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate = (&#10;&#9;&#9;SELECT &#10;&#9;&#9;&#9;max(</xsl:text>
					<xsl:text>sub.</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate) &#10;&#9;&#9;FROM &#10;&#9;&#9;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@name"/>
					<xsl:text> sub &#10;&#9;&#9;WHERE &#10;&#9;&#9;&#9;sub.</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>_ID &#10;&#9;&#9;AND &#10;&#9;&#9;&#9;sub.</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate &lt;= [</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>]._inspectedDate</xsl:text>
					<xsl:text>&#10;&#9;)</xsl:text>
				</xsl:if>
				<xsl:if test="am:relation">
					<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@name"/>
					<xsl:text>&#32;[</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_ID</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>;&#10;GO&#10;</xsl:text>

			<!-- create the extended difference function -->

			<xsl:text>IF EXISTS (SELECT * FROM sys.objects WHERE name = 'x</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%F%')&#10;</xsl:text>
			<xsl:text>DROP FUNCTION [x</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>]; &#10;GO&#10;</xsl:text>
			<xsl:text>CREATE FUNCTION [x</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] (&#10;&#9;@intervalStart </xsl:text>
			<xsl:value-of select="$globalHistorizationType"/>
			<xsl:text>, &#10;&#9;@intervalEnd </xsl:text>
			<xsl:value-of select="$globalHistorizationType"/>
			<xsl:text>, &#10;&#9;@columns xml = '</xsl:text>
			<xsl:for-each select="am:attribute[@historized = 'true']">
				<xsl:text>&#10;&#9;&#9;&lt;col&gt;</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate&lt;/col&gt;</xsl:text>
			</xsl:for-each>
			<xsl:text>&#10;&#9;'&#10;) &#10;RETURNS TABLE RETURN &#10;SELECT &#10;&#9;</xsl:text>
			<xsl:choose>
				<xsl:when test="am:attribute[@historized = 'true']">
					<xsl:text>[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>]._inspectedDate, &#10;&#9;</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>NULL as _inspectedDate, &#10;&#9;</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>[</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>].</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_ID</xsl:text>
			<xsl:if test="am:attribute">
				<xsl:text>, &#10;&#9;</xsl:text>
			</xsl:if>
			<xsl:for-each select="am:attribute">
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', am:relation/@reference)">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="am:relation/@reference"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@name"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="@historized = 'true'">
					<xsl:text>, &#10;&#9;[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate</xsl:text>
				</xsl:if>
				<xsl:if test="not(position() = last())">
					<xsl:text>, &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#10;FROM </xsl:text>
			<xsl:choose>
				<xsl:when test="am:attribute[@historized = 'true']">
					<xsl:text>(&#10;&#9;SELECT DISTINCT &#10;&#9;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_ID, &#10;&#9;&#9;_inspectedDate &#10;&#9;FROM (&#10;&#9;&#9;SELECT &#10;&#9;&#9;&#9;[s</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_ID, &#10;&#9;&#9;&#9;</xsl:text>
					<xsl:for-each select="am:attribute[@historized = 'true']">
						<xsl:text>[s</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_FromDate</xsl:text>
						<xsl:if test="not(position() = last())">
							<xsl:text>, &#10;&#9;&#9;&#9;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:text>&#10;&#9;&#9;FROM &#10;&#9;&#9;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@name"/>
					<xsl:text> [s</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>]</xsl:text>
					<xsl:for-each select="am:attribute[@historized = 'true']">
						<xsl:text>&#10;&#9;&#9;LEFT JOIN &#10;&#9;&#9;&#9;</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@name"/>
						<xsl:text> [s</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>]&#10;&#9;&#9;ON &#10;&#9;&#9;&#9;[s</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="parent::am:anchor/@mnemonic"/>
						<xsl:text>_ID = [s</xsl:text>
						<xsl:value-of select="parent::am:anchor/@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="parent::am:anchor/@mnemonic"/>
						<xsl:text>_ID</xsl:text>
						<xsl:text>&#10;&#9;&#9;AND &#10;&#9;&#9;&#9;[s</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_FromDate between @intervalStart and @intervalEnd</xsl:text>
					</xsl:for-each>
					<xsl:text>&#10;&#9;) piv &#10;&#9;UNPIVOT (&#10;&#9;&#9;_inspectedDate for _historizationColumn in (&#10;&#9;&#9;&#9;</xsl:text>
					<xsl:for-each select="am:attribute[@historized = 'true']">
						<xsl:value-of select="@mnemonic"/>
						<xsl:text>_FromDate</xsl:text>
						<xsl:if test="not(position() = last())">
							<xsl:text>, &#10;&#9;&#9;&#9;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:text>&#10;&#9;&#9;) &#10;&#9;) unpiv &#10;&#9;WHERE &#10;&#9;&#9; _historizationColumn IN ((select name.value('.', 'varchar(255)') from @columns.nodes('/col') as T(name)))&#10;) </xsl:text>
					<xsl:value-of select="@mnemonic"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>&#10;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@name"/>
					<xsl:text>&#32;[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>]</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:for-each select="am:attribute">
				<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_</xsl:text>
				<xsl:value-of select="@name"/>
				<xsl:text>&#32;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID = [</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="parent::am:anchor/@mnemonic"/>
				<xsl:text>_ID</xsl:text>
				<xsl:if test="@historized = 'true'">
					<xsl:text>&#10;AND &#10;&#9;[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate = (&#10;&#9;&#9;SELECT &#10;&#9;&#9;&#9;max(</xsl:text>
					<xsl:text>sub.</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate) &#10;&#9;&#9;FROM &#10;&#9;&#9;&#9;</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@name"/>
					<xsl:text> sub &#10;&#9;&#9;WHERE &#10;&#9;&#9;&#9;sub.</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>_ID &#10;&#9;&#9;AND &#10;&#9;&#9;&#9;sub.</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate &lt;= [</xsl:text>
					<xsl:value-of select="parent::am:anchor/@mnemonic"/>
					<xsl:text>]._inspectedDate</xsl:text>
					<xsl:text>&#10;&#9;)</xsl:text>
				</xsl:if>
				<xsl:if test="am:relation">
					<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="key('mnemonicToEntity', am:relation/@reference)/@name"/>
					<xsl:text>&#32;[</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="am:relation/@reference"/>
					<xsl:text>_ID</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>;&#10;GO&#10;</xsl:text>
		</xsl:for-each>

		<!-- process all ties -->

		<xsl:for-each select="am:tie">
			<xsl:text>IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = '</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%U%')&#10;</xsl:text>
			<xsl:text>CREATE TABLE [</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] ( &#10;&#9;</xsl:text>
			<xsl:for-each select="am:relation">
				<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
				<xsl:text>_ID</xsl:text>
				<xsl:variable name="currentReference" select="@reference"/>
				<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@ordinal"/>
				</xsl:if>
				<xsl:text>&#32;</xsl:text>
				<xsl:value-of select="key('mnemonicToEntity', @reference)/@idType"/>
				<xsl:text> not null, &#10;&#9;</xsl:text>
			</xsl:for-each>
			<xsl:if test="@historized = 'true'">
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate </xsl:text>
				<xsl:value-of select="$globalHistorizationType"/>
				<xsl:text> not null, &#10;&#9;</xsl:text>
			</xsl:if>
			<xsl:value-of select="$metadata"/>
			<xsl:text>, &#10;&#9;PRIMARY KEY (</xsl:text>
			<xsl:for-each select="am:relation[@primary = 'true']">
				<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
				<xsl:text>_ID</xsl:text>
				<xsl:variable name="currentReference" select="@reference"/>
				<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@ordinal"/>
				</xsl:if>
				<xsl:text> asc</xsl:text>
				<xsl:if test="not(position() = last())">
					<xsl:text>, </xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test="@historized = 'true'">
				<xsl:text>, </xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate desc</xsl:text>
			</xsl:if>
			<xsl:text>) &#10;);&#10;GO&#10;</xsl:text>

			<!-- create the latest view -->

			<xsl:text>IF EXISTS (SELECT * FROM sys.objects WHERE name = 'l</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%V%')&#10;</xsl:text>
			<xsl:text>DROP VIEW [l</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>]; &#10;GO&#10;</xsl:text>
			<xsl:text>CREATE VIEW [l</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] AS &#10;SELECT &#10;&#9;</xsl:text>
			<xsl:for-each select="am:relation">
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', @reference)[local-name() = 'knot']">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
						<xsl:variable name="currentReference" select="@reference"/>
						<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
							<xsl:value-of select="@ordinal"/>
						</xsl:if>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="parent::am:tie/@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
						<xsl:text>_ID</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:variable name="currentReference" select="@reference"/>
				<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@ordinal"/>
				</xsl:if>
				<xsl:if test="not(position() = last())">
					<xsl:text>, &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test="@historized = 'true'">
				<xsl:text>, &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate</xsl:text>
			</xsl:if>
			<xsl:text>&#10;FROM &#10;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>&#32;[</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>]</xsl:text>
			<xsl:variable name="tieMnemonic" select="@mnemonic"/>
			<xsl:for-each select="am:relation">
				<xsl:variable name="knot" select="key('mnemonicToEntity', @reference)[local-name() = 'knot']"/>
				<xsl:if test="$knot">					
					<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="$knot/@name"/>
					<xsl:text>&#32;[</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:variable name="currentReference" select="@reference"/>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="$tieMnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:text>_ID</xsl:text>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test="@historized = 'true'">
				<xsl:text>&#10;WHERE &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate = (&#10;&#9;&#9;SELECT &#10;&#9;&#9;&#9;max(</xsl:text>
				<xsl:text>sub.</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate) &#10;&#9;&#9;FROM &#10;&#9;&#9;&#9;</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_</xsl:text>
				<xsl:value-of select="@name"/>
				<xsl:text> sub &#10;&#9;&#9;WHERE </xsl:text>
				<xsl:for-each select="am:relation[@primary = 'true']">
					<xsl:text>&#10;&#9;&#9;&#9;sub.</xsl:text>
					<xsl:value-of select="@reference"/>
					<xsl:text>_ID</xsl:text>
					<xsl:variable name="currentReference" select="@reference"/>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:text> = [</xsl:text>
					<xsl:value-of select="parent::am:tie/@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@reference"/>
					<xsl:text>_ID</xsl:text>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:if test="not(position() = last())">
						<xsl:text>&#10;&#9;&#9;AND </xsl:text>
					</xsl:if>
				</xsl:for-each>
				<xsl:text>&#10;&#9;)</xsl:text>
			</xsl:if>
			<xsl:text>;&#10;GO&#10;</xsl:text>

			<!-- create the point-in-time function -->

			<xsl:text>IF EXISTS (SELECT * FROM sys.objects WHERE name = 'p</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%F%')&#10;</xsl:text>
			<xsl:text>DROP FUNCTION [p</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>]; &#10;GO&#10;</xsl:text>
			<xsl:text>CREATE FUNCTION [p</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] (@timepoint </xsl:text>
			<xsl:value-of select="$globalHistorizationType"/>
			<xsl:text>) &#10;RETURNS TABLE RETURN &#10;SELECT &#10;&#9;</xsl:text>
			<xsl:for-each select="am:relation">
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', @reference)[local-name() = 'knot']">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
						<xsl:variable name="currentReference" select="@reference"/>
						<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
							<xsl:value-of select="@ordinal"/>
						</xsl:if>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="parent::am:tie/@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
						<xsl:text>_ID</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:variable name="currentReference" select="@reference"/>
				<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@ordinal"/>
				</xsl:if>
				<xsl:if test="not(position() = last())">
					<xsl:text>, &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test="@historized = 'true'">
				<xsl:text>, &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate</xsl:text>
			</xsl:if>
			<xsl:text>&#10;FROM &#10;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>&#32;[</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>]</xsl:text>
			<xsl:for-each select="am:relation">
				<xsl:variable name="knot" select="key('mnemonicToEntity', @reference)[local-name() = 'knot']"/>
				<xsl:if test="$knot">
					<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="$knot/@name"/>
					<xsl:text>&#32;[</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:variable name="currentReference" select="@reference"/>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="$tieMnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:text>_ID</xsl:text>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test="@historized = 'true'">
				<xsl:text>&#10;WHERE &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate = (&#10;&#9;&#9;SELECT &#10;&#9;&#9;&#9;max(</xsl:text>
				<xsl:text>sub.</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate) &#10;&#9;&#9;FROM &#10;&#9;&#9;&#9;</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_</xsl:text>
				<xsl:value-of select="@name"/>
				<xsl:text> sub &#10;&#9;&#9;WHERE </xsl:text>
				<xsl:for-each select="am:relation[@primary = 'true']">
					<xsl:text>&#10;&#9;&#9;&#9;sub.</xsl:text>
					<xsl:value-of select="@reference"/>
					<xsl:text>_ID</xsl:text>
					<xsl:variable name="currentReference" select="@reference"/>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:text> = [</xsl:text>
					<xsl:value-of select="parent::am:tie/@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@reference"/>
					<xsl:text>_ID</xsl:text>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:if test="not(position() = last())">
						<xsl:text>&#10;&#9;&#9;AND </xsl:text>
					</xsl:if>
				</xsl:for-each>
				<xsl:text>&#10;&#9;&#9;AND &#10;&#9;&#9;&#9;sub.</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate &lt;= @timepoint</xsl:text>
				<xsl:text>&#10;&#9;)</xsl:text>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="am:relation[not(@primary = 'true')] and @historized = 'true'">
					<xsl:text>&#10;AND &#10;&#9;</xsl:text>
				</xsl:when>
				<xsl:when test="am:relation[not(@primary = 'true')] and not(@historized = 'true')">
					<xsl:text>&#10;WHERE &#10;&#9;</xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="am:relation[not(@primary = 'true')]">
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', @reference)[local-name() = 'knot']">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="@reference"/>
						<xsl:variable name="currentReference" select="@reference"/>
						<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
							<xsl:value-of select="@ordinal"/>
						</xsl:if>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@reference"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="$tieMnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@reference"/>
						<xsl:text>_ID</xsl:text>
						<xsl:variable name="currentReference" select="@reference"/>
						<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
							<xsl:text>_</xsl:text>
							<xsl:value-of select="@ordinal"/>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text> is not null</xsl:text>
				<xsl:if test="not(position() = last())">
					<xsl:text>&#10;OR &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>;&#10;GO&#10;</xsl:text>

			<!-- create the difference function -->

			<xsl:text>IF EXISTS (SELECT * FROM sys.objects WHERE name = 'd</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>' and type LIKE '%F%')&#10;</xsl:text>
			<xsl:text>DROP FUNCTION [d</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>]; &#10;GO&#10;</xsl:text>
			<xsl:text>CREATE FUNCTION [d</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>] (@intervalStart </xsl:text>
			<xsl:value-of select="$globalHistorizationType"/>
			<xsl:text>, @intervalEnd </xsl:text>
			<xsl:value-of select="$globalHistorizationType"/>
			<xsl:text>) &#10;RETURNS TABLE RETURN &#10;SELECT &#10;&#9;</xsl:text>
			<xsl:choose>
				<xsl:when test="@historized = 'true'">
					<xsl:text>[</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="@mnemonic"/>
					<xsl:text>_FromDate as _inspectedDate, &#10;&#9;</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>NULL as _inspectedDate, &#10;&#9;</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:for-each select="am:relation">
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', @reference)[local-name() = 'knot']">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
						<xsl:variable name="currentReference" select="@reference"/>
						<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
							<xsl:value-of select="@ordinal"/>
						</xsl:if>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="parent::am:tie/@mnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@mnemonic"/>
						<xsl:text>_ID</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:variable name="currentReference" select="@reference"/>
				<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
					<xsl:text>_</xsl:text>
					<xsl:value-of select="@ordinal"/>
				</xsl:if>
				<xsl:if test="not(position() = last())">
					<xsl:text>, &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test="@historized = 'true'">
				<xsl:text>, &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate</xsl:text>
			</xsl:if>
			<xsl:text>&#10;FROM &#10;&#9;</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>_</xsl:text>
			<xsl:value-of select="@name"/>
			<xsl:text>&#32;[</xsl:text>
			<xsl:value-of select="@mnemonic"/>
			<xsl:text>]</xsl:text>
			<xsl:for-each select="am:relation">
				<xsl:variable name="knot" select="key('mnemonicToEntity', @reference)[local-name() = 'knot']"/>
				<xsl:if test="$knot">
					<xsl:text>&#10;LEFT JOIN &#10;&#9;</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:text>_</xsl:text>
					<xsl:value-of select="$knot/@name"/>
					<xsl:text>&#32;[</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:variable name="currentReference" select="@reference"/>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:text>]&#10;ON &#10;&#9;[</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:text>_ID = [</xsl:text>
					<xsl:value-of select="$tieMnemonic"/>
					<xsl:text>].</xsl:text>
					<xsl:value-of select="$knot/@mnemonic"/>
					<xsl:text>_ID</xsl:text>
					<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
						<xsl:text>_</xsl:text>
						<xsl:value-of select="@ordinal"/>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test="@historized = 'true'">
				<xsl:text>&#10;WHERE &#10;&#9;[</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>].</xsl:text>
				<xsl:value-of select="@mnemonic"/>
				<xsl:text>_FromDate between @intervalStart and @intervalEnd</xsl:text>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="am:relation[not(@primary = 'true')] and @historized = 'true'">
					<xsl:text>&#10;AND &#10;&#9;</xsl:text>
				</xsl:when>
				<xsl:when test="am:relation[not(@primary = 'true')] and not(@historized = 'true')">
					<xsl:text>&#10;WHERE &#10;&#9;</xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="am:relation[not(@primary = 'true')]">
				<xsl:choose>
					<xsl:when test="key('mnemonicToEntity', @reference)[local-name() = 'knot']">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="@reference"/>
						<xsl:variable name="currentReference" select="@reference"/>
						<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
							<xsl:value-of select="@ordinal"/>
						</xsl:if>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@reference"/>
						<xsl:text>_</xsl:text>
						<xsl:value-of select="key('mnemonicToEntity', @reference)/@name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[</xsl:text>
						<xsl:value-of select="$tieMnemonic"/>
						<xsl:text>].</xsl:text>
						<xsl:value-of select="@reference"/>
						<xsl:text>_ID</xsl:text>
						<xsl:variable name="currentReference" select="@reference"/>
						<xsl:if test="count(../am:relation[@reference = $currentReference]) > 1">
							<xsl:text>_</xsl:text>
							<xsl:value-of select="@ordinal"/>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text> is not null</xsl:text>
				<xsl:if test="not(position() = last())">
					<xsl:text>&#10;OR &#10;&#9;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>;&#10;GO&#10;</xsl:text>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>
