IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'GEN_Gender' and type LIKE '%U%')
CREATE TABLE [GEN_Gender] ( 
	GEN_ID bit not null, 
	GEN_Gender varchar(6) not null, 
	_metadata int not null, 
	PRIMARY KEY (GEN_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'RAT_Rating' and type LIKE '%U%')
CREATE TABLE [RAT_Rating] ( 
	RAT_ID tinyint not null, 
	RAT_Rating varchar(10) not null, 
	_metadata int not null, 
	PRIMARY KEY (RAT_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PLV_ProfessionalLevel' and type LIKE '%U%')
CREATE TABLE [PLV_ProfessionalLevel] ( 
	PLV_ID tinyint not null, 
	PLV_ProfessionalLevel varchar(10) not null, 
	_metadata int not null, 
	PRIMARY KEY (PLV_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PAR_Parenthood' and type LIKE '%U%')
CREATE TABLE [PAR_Parenthood] ( 
	PAR_ID bit not null, 
	PAR_Parenthood varchar(6) not null, 
	_metadata int not null, 
	PRIMARY KEY (PAR_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'AC_Actor' and type LIKE '%U%')
CREATE TABLE [AC_Actor] ( 
	AC_ID int not null, 
	_metadata int not null, 
	PRIMARY KEY (AC_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'ACNAM_ActorName' and type LIKE '%U%')
CREATE TABLE [ACNAM_ActorName] ( 
	AC_ID int not null, 
	ACNAM_ActorName varchar(42) not null, 
	ACNAM_FromDate datetime not null, 
	_metadata int not null, 
	PRIMARY KEY (AC_ID asc, ACNAM_FromDate desc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'ACGEN_ActorGender' and type LIKE '%U%')
CREATE TABLE [ACGEN_ActorGender] ( 
	AC_ID int not null, 
	GEN_ID bit not null, 
	_metadata int not null, 
	PRIMARY KEY (AC_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'ACPLV_ActorProfessionalLevel' and type LIKE '%U%')
CREATE TABLE [ACPLV_ActorProfessionalLevel] ( 
	AC_ID int not null, 
	PLV_ID tinyint not null, 
	ACPLV_FromDate datetime not null, 
	_metadata int not null, 
	PRIMARY KEY (AC_ID asc, ACPLV_FromDate desc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lAC_Actor' and type LIKE '%V%')
DROP VIEW [lAC_Actor]; 
GO
CREATE VIEW [lAC_Actor] AS 
SELECT 
	AC.AC_ID, 
	ACNAM.ACNAM_ActorName, 
	ACNAM.ACNAM_FromDate, 
	GEN.GEN_Gender, 
	PLV.PLV_ProfessionalLevel, 
	ACPLV.ACPLV_FromDate
FROM 
	AC_Actor AC
LEFT JOIN 
	ACNAM_ActorName ACNAM
ON 
	ACNAM.AC_ID = AC.AC_ID
AND 
	ACNAM.ACNAM_FromDate = (
		SELECT 
			max(sub.ACNAM_FromDate) 
		FROM 
			ACNAM_ActorName sub 
		WHERE 
			sub.AC_ID = AC.AC_ID 
	)
LEFT JOIN 
	ACGEN_ActorGender ACGEN
ON 
	ACGEN.AC_ID = AC.AC_ID
LEFT JOIN 
	GEN_Gender GEN
ON 
	GEN.GEN_ID = ACGEN.GEN_ID
LEFT JOIN 
	ACPLV_ActorProfessionalLevel ACPLV
ON 
	ACPLV.AC_ID = AC.AC_ID
AND 
	ACPLV.ACPLV_FromDate = (
		SELECT 
			max(sub.ACPLV_FromDate) 
		FROM 
			ACPLV_ActorProfessionalLevel sub 
		WHERE 
			sub.AC_ID = AC.AC_ID 
	)
LEFT JOIN 
	PLV_ProfessionalLevel PLV
ON 
	PLV.PLV_ID = ACPLV.PLV_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pAC_Actor' and type LIKE '%F%')
DROP FUNCTION [pAC_Actor]; 
GO
CREATE FUNCTION [pAC_Actor] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	AC.AC_ID, 
	ACNAM.ACNAM_ActorName, 
	ACNAM.ACNAM_FromDate, 
	GEN.GEN_Gender, 
	PLV.PLV_ProfessionalLevel, 
	ACPLV.ACPLV_FromDate
FROM 
	AC_Actor AC
LEFT JOIN 
	ACNAM_ActorName ACNAM
ON 
	ACNAM.AC_ID = AC.AC_ID
AND 
	ACNAM.ACNAM_FromDate = (
		SELECT 
			max(sub.ACNAM_FromDate) 
		FROM 
			ACNAM_ActorName sub 
		WHERE 
			sub.AC_ID = AC.AC_ID 
		AND 
			sub.ACNAM_FromDate <= @timepoint
	)
LEFT JOIN 
	ACGEN_ActorGender ACGEN
ON 
	ACGEN.AC_ID = AC.AC_ID
LEFT JOIN 
	GEN_Gender GEN
ON 
	GEN.GEN_ID = ACGEN.GEN_ID
LEFT JOIN 
	ACPLV_ActorProfessionalLevel ACPLV
ON 
	ACPLV.AC_ID = AC.AC_ID
AND 
	ACPLV.ACPLV_FromDate = (
		SELECT 
			max(sub.ACPLV_FromDate) 
		FROM 
			ACPLV_ActorProfessionalLevel sub 
		WHERE 
			sub.AC_ID = AC.AC_ID 
		AND 
			sub.ACPLV_FromDate <= @timepoint
	)
LEFT JOIN 
	PLV_ProfessionalLevel PLV
ON 
	PLV.PLV_ID = ACPLV.PLV_ID
WHERE 
	ACNAM.ACNAM_ActorName is not null
OR 
	PLV.PLV_ProfessionalLevel is not null;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dAC_Actor' and type LIKE '%F%')
DROP FUNCTION [dAC_Actor]; 
GO
CREATE FUNCTION [dAC_Actor] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	AC._inspectedDate, 
	AC.AC_ID, 
	ACNAM.ACNAM_ActorName, 
	ACNAM.ACNAM_FromDate, 
	GEN.GEN_Gender, 
	PLV.PLV_ProfessionalLevel, 
	ACPLV.ACPLV_FromDate
FROM (
	SELECT DISTINCT 
		AC_ID, 
		_inspectedDate 
	FROM (
		SELECT 
			sAC.AC_ID, 
			sACNAM.ACNAM_FromDate, 
			sACPLV.ACPLV_FromDate
		FROM 
			AC_Actor sAC
		LEFT JOIN 
			ACNAM_ActorName sACNAM
		ON 
			sACNAM.AC_ID = sAC.AC_ID
		AND 
			sACNAM.ACNAM_FromDate between @intervalStart and @intervalEnd
		LEFT JOIN 
			ACPLV_ActorProfessionalLevel sACPLV
		ON 
			sACPLV.AC_ID = sAC.AC_ID
		AND 
			sACPLV.ACPLV_FromDate between @intervalStart and @intervalEnd
	) piv 
	UNPIVOT (
		_inspectedDate for _historizationColumn in (
			ACNAM_FromDate, 
			ACPLV_FromDate
		) 
	) unpiv 
) AC
LEFT JOIN 
	ACNAM_ActorName ACNAM
ON 
	ACNAM.AC_ID = AC.AC_ID
AND 
	ACNAM.ACNAM_FromDate = (
		SELECT 
			max(sub.ACNAM_FromDate) 
		FROM 
			ACNAM_ActorName sub 
		WHERE 
			sub.AC_ID = AC.AC_ID 
		AND 
			sub.ACNAM_FromDate <= AC._inspectedDate
	)
LEFT JOIN 
	ACGEN_ActorGender ACGEN
ON 
	ACGEN.AC_ID = AC.AC_ID
LEFT JOIN 
	GEN_Gender GEN
ON 
	GEN.GEN_ID = ACGEN.GEN_ID
LEFT JOIN 
	ACPLV_ActorProfessionalLevel ACPLV
ON 
	ACPLV.AC_ID = AC.AC_ID
AND 
	ACPLV.ACPLV_FromDate = (
		SELECT 
			max(sub.ACPLV_FromDate) 
		FROM 
			ACPLV_ActorProfessionalLevel sub 
		WHERE 
			sub.AC_ID = AC.AC_ID 
		AND 
			sub.ACPLV_FromDate <= AC._inspectedDate
	)
LEFT JOIN 
	PLV_ProfessionalLevel PLV
ON 
	PLV.PLV_ID = ACPLV.PLV_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'xAC_Actor' and type LIKE '%F%')
DROP FUNCTION [xAC_Actor]; 
GO
CREATE FUNCTION [xAC_Actor] (
	@intervalStart datetime, 
	@intervalEnd datetime, 
	@columns xml = '
		<col>ACNAM_FromDate</col>
		<col>ACPLV_FromDate</col>
	'
) 
RETURNS TABLE RETURN 
SELECT 
	AC._inspectedDate, 
	AC.AC_ID, 
	ACNAM.ACNAM_ActorName, 
	ACNAM.ACNAM_FromDate, 
	GEN.GEN_Gender, 
	PLV.PLV_ProfessionalLevel, 
	ACPLV.ACPLV_FromDate
FROM (
	SELECT DISTINCT 
		AC_ID, 
		_inspectedDate 
	FROM (
		SELECT 
			sAC.AC_ID, 
			sACNAM.ACNAM_FromDate, 
			sACPLV.ACPLV_FromDate
		FROM 
			AC_Actor sAC
		LEFT JOIN 
			ACNAM_ActorName sACNAM
		ON 
			sACNAM.AC_ID = sAC.AC_ID
		AND 
			sACNAM.ACNAM_FromDate between @intervalStart and @intervalEnd
		LEFT JOIN 
			ACPLV_ActorProfessionalLevel sACPLV
		ON 
			sACPLV.AC_ID = sAC.AC_ID
		AND 
			sACPLV.ACPLV_FromDate between @intervalStart and @intervalEnd
	) piv 
	UNPIVOT (
		_inspectedDate for _historizationColumn in (
			ACNAM_FromDate, 
			ACPLV_FromDate
		) 
	) unpiv 
	WHERE 
		 _historizationColumn IN ((select name.value('.', 'varchar(255)') from @columns.nodes('/col') as T(name)))
) AC
LEFT JOIN 
	ACNAM_ActorName ACNAM
ON 
	ACNAM.AC_ID = AC.AC_ID
AND 
	ACNAM.ACNAM_FromDate = (
		SELECT 
			max(sub.ACNAM_FromDate) 
		FROM 
			ACNAM_ActorName sub 
		WHERE 
			sub.AC_ID = AC.AC_ID 
		AND 
			sub.ACNAM_FromDate <= AC._inspectedDate
	)
LEFT JOIN 
	ACGEN_ActorGender ACGEN
ON 
	ACGEN.AC_ID = AC.AC_ID
LEFT JOIN 
	GEN_Gender GEN
ON 
	GEN.GEN_ID = ACGEN.GEN_ID
LEFT JOIN 
	ACPLV_ActorProfessionalLevel ACPLV
ON 
	ACPLV.AC_ID = AC.AC_ID
AND 
	ACPLV.ACPLV_FromDate = (
		SELECT 
			max(sub.ACPLV_FromDate) 
		FROM 
			ACPLV_ActorProfessionalLevel sub 
		WHERE 
			sub.AC_ID = AC.AC_ID 
		AND 
			sub.ACPLV_FromDate <= AC._inspectedDate
	)
LEFT JOIN 
	PLV_ProfessionalLevel PLV
ON 
	PLV.PLV_ID = ACPLV.PLV_ID;
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PR_Program' and type LIKE '%U%')
CREATE TABLE [PR_Program] ( 
	PR_ID int not null, 
	_metadata int not null, 
	PRIMARY KEY (PR_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PRNAM_ProgramName' and type LIKE '%U%')
CREATE TABLE [PRNAM_ProgramName] ( 
	PR_ID int not null, 
	PRNAM_ProgramName varchar(42) not null, 
	_metadata int not null, 
	PRIMARY KEY (PR_ID asc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lPR_Program' and type LIKE '%V%')
DROP VIEW [lPR_Program]; 
GO
CREATE VIEW [lPR_Program] AS 
SELECT 
	PR.PR_ID, 
	PRNAM.PRNAM_ProgramName
FROM 
	PR_Program PR
LEFT JOIN 
	PRNAM_ProgramName PRNAM
ON 
	PRNAM.PR_ID = PR.PR_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pPR_Program' and type LIKE '%F%')
DROP FUNCTION [pPR_Program]; 
GO
CREATE FUNCTION [pPR_Program] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	PR.PR_ID, 
	PRNAM.PRNAM_ProgramName
FROM 
	PR_Program PR
LEFT JOIN 
	PRNAM_ProgramName PRNAM
ON 
	PRNAM.PR_ID = PR.PR_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dPR_Program' and type LIKE '%F%')
DROP FUNCTION [dPR_Program]; 
GO
CREATE FUNCTION [dPR_Program] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	NULL as _inspectedDate, 
	PR.PR_ID, 
	PRNAM.PRNAM_ProgramName
FROM 
	PR_Program PR
LEFT JOIN 
	PRNAM_ProgramName PRNAM
ON 
	PRNAM.PR_ID = PR.PR_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'xPR_Program' and type LIKE '%F%')
DROP FUNCTION [xPR_Program]; 
GO
CREATE FUNCTION [xPR_Program] (
	@intervalStart datetime, 
	@intervalEnd datetime, 
	@columns xml = '
	'
) 
RETURNS TABLE RETURN 
SELECT 
	NULL as _inspectedDate, 
	PR.PR_ID, 
	PRNAM.PRNAM_ProgramName
FROM 
	PR_Program PR
LEFT JOIN 
	PRNAM_ProgramName PRNAM
ON 
	PRNAM.PR_ID = PR.PR_ID;
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'ST_Stage' and type LIKE '%U%')
CREATE TABLE [ST_Stage] ( 
	ST_ID int not null, 
	_metadata int not null, 
	PRIMARY KEY (ST_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'STNAM_StageName' and type LIKE '%U%')
CREATE TABLE [STNAM_StageName] ( 
	ST_ID int not null, 
	STNAM_StageName varchar(42) not null, 
	STNAM_FromDate datetime not null, 
	_metadata int not null, 
	PRIMARY KEY (ST_ID asc, STNAM_FromDate desc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'STLOC_StageLocation' and type LIKE '%U%')
CREATE TABLE [STLOC_StageLocation] ( 
	ST_ID int not null, 
	STLOC_StageLocation varchar(42) not null, 
	_metadata int not null, 
	PRIMARY KEY (ST_ID asc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lST_Stage' and type LIKE '%V%')
DROP VIEW [lST_Stage]; 
GO
CREATE VIEW [lST_Stage] AS 
SELECT 
	ST.ST_ID, 
	STNAM.STNAM_StageName, 
	STNAM.STNAM_FromDate, 
	STLOC.STLOC_StageLocation
FROM 
	ST_Stage ST
LEFT JOIN 
	STNAM_StageName STNAM
ON 
	STNAM.ST_ID = ST.ST_ID
AND 
	STNAM.STNAM_FromDate = (
		SELECT 
			max(sub.STNAM_FromDate) 
		FROM 
			STNAM_StageName sub 
		WHERE 
			sub.ST_ID = ST.ST_ID 
	)
LEFT JOIN 
	STLOC_StageLocation STLOC
ON 
	STLOC.ST_ID = ST.ST_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pST_Stage' and type LIKE '%F%')
DROP FUNCTION [pST_Stage]; 
GO
CREATE FUNCTION [pST_Stage] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	ST.ST_ID, 
	STNAM.STNAM_StageName, 
	STNAM.STNAM_FromDate, 
	STLOC.STLOC_StageLocation
FROM 
	ST_Stage ST
LEFT JOIN 
	STNAM_StageName STNAM
ON 
	STNAM.ST_ID = ST.ST_ID
AND 
	STNAM.STNAM_FromDate = (
		SELECT 
			max(sub.STNAM_FromDate) 
		FROM 
			STNAM_StageName sub 
		WHERE 
			sub.ST_ID = ST.ST_ID 
		AND 
			sub.STNAM_FromDate <= @timepoint
	)
LEFT JOIN 
	STLOC_StageLocation STLOC
ON 
	STLOC.ST_ID = ST.ST_ID
WHERE 
	STNAM.STNAM_StageName is not null;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dST_Stage' and type LIKE '%F%')
DROP FUNCTION [dST_Stage]; 
GO
CREATE FUNCTION [dST_Stage] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	ST._inspectedDate, 
	ST.ST_ID, 
	STNAM.STNAM_StageName, 
	STNAM.STNAM_FromDate, 
	STLOC.STLOC_StageLocation
FROM (
	SELECT DISTINCT 
		ST_ID, 
		_inspectedDate 
	FROM (
		SELECT 
			sST.ST_ID, 
			sSTNAM.STNAM_FromDate
		FROM 
			ST_Stage sST
		LEFT JOIN 
			STNAM_StageName sSTNAM
		ON 
			sSTNAM.ST_ID = sST.ST_ID
		AND 
			sSTNAM.STNAM_FromDate between @intervalStart and @intervalEnd
	) piv 
	UNPIVOT (
		_inspectedDate for _historizationColumn in (
			STNAM_FromDate
		) 
	) unpiv 
) ST
LEFT JOIN 
	STNAM_StageName STNAM
ON 
	STNAM.ST_ID = ST.ST_ID
AND 
	STNAM.STNAM_FromDate = (
		SELECT 
			max(sub.STNAM_FromDate) 
		FROM 
			STNAM_StageName sub 
		WHERE 
			sub.ST_ID = ST.ST_ID 
		AND 
			sub.STNAM_FromDate <= ST._inspectedDate
	)
LEFT JOIN 
	STLOC_StageLocation STLOC
ON 
	STLOC.ST_ID = ST.ST_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'xST_Stage' and type LIKE '%F%')
DROP FUNCTION [xST_Stage]; 
GO
CREATE FUNCTION [xST_Stage] (
	@intervalStart datetime, 
	@intervalEnd datetime, 
	@columns xml = '
		<col>STNAM_FromDate</col>
	'
) 
RETURNS TABLE RETURN 
SELECT 
	ST._inspectedDate, 
	ST.ST_ID, 
	STNAM.STNAM_StageName, 
	STNAM.STNAM_FromDate, 
	STLOC.STLOC_StageLocation
FROM (
	SELECT DISTINCT 
		ST_ID, 
		_inspectedDate 
	FROM (
		SELECT 
			sST.ST_ID, 
			sSTNAM.STNAM_FromDate
		FROM 
			ST_Stage sST
		LEFT JOIN 
			STNAM_StageName sSTNAM
		ON 
			sSTNAM.ST_ID = sST.ST_ID
		AND 
			sSTNAM.STNAM_FromDate between @intervalStart and @intervalEnd
	) piv 
	UNPIVOT (
		_inspectedDate for _historizationColumn in (
			STNAM_FromDate
		) 
	) unpiv 
	WHERE 
		 _historizationColumn IN ((select name.value('.', 'varchar(255)') from @columns.nodes('/col') as T(name)))
) ST
LEFT JOIN 
	STNAM_StageName STNAM
ON 
	STNAM.ST_ID = ST.ST_ID
AND 
	STNAM.STNAM_FromDate = (
		SELECT 
			max(sub.STNAM_FromDate) 
		FROM 
			STNAM_StageName sub 
		WHERE 
			sub.ST_ID = ST.ST_ID 
		AND 
			sub.STNAM_FromDate <= ST._inspectedDate
	)
LEFT JOIN 
	STLOC_StageLocation STLOC
ON 
	STLOC.ST_ID = ST.ST_ID;
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PE_Performance' and type LIKE '%U%')
CREATE TABLE [PE_Performance] ( 
	PE_ID int not null, 
	_metadata int not null, 
	PRIMARY KEY (PE_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PEDAT_PerformanceDate' and type LIKE '%U%')
CREATE TABLE [PEDAT_PerformanceDate] ( 
	PE_ID int not null, 
	PEDAT_PerformanceDate datetime not null, 
	_metadata int not null, 
	PRIMARY KEY (PE_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PEAUD_PerformanceAudience' and type LIKE '%U%')
CREATE TABLE [PEAUD_PerformanceAudience] ( 
	PE_ID int not null, 
	PEAUD_PerformanceAudience int not null, 
	_metadata int not null, 
	PRIMARY KEY (PE_ID asc) 
);
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PEREV_PerformanceRevenue' and type LIKE '%U%')
CREATE TABLE [PEREV_PerformanceRevenue] ( 
	PE_ID int not null, 
	PEREV_PerformanceRevenue money not null, 
	_metadata int not null, 
	PRIMARY KEY (PE_ID asc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lPE_Performance' and type LIKE '%V%')
DROP VIEW [lPE_Performance]; 
GO
CREATE VIEW [lPE_Performance] AS 
SELECT 
	PE.PE_ID, 
	PEDAT.PEDAT_PerformanceDate, 
	PEAUD.PEAUD_PerformanceAudience, 
	PEREV.PEREV_PerformanceRevenue
FROM 
	PE_Performance PE
LEFT JOIN 
	PEDAT_PerformanceDate PEDAT
ON 
	PEDAT.PE_ID = PE.PE_ID
LEFT JOIN 
	PEAUD_PerformanceAudience PEAUD
ON 
	PEAUD.PE_ID = PE.PE_ID
LEFT JOIN 
	PEREV_PerformanceRevenue PEREV
ON 
	PEREV.PE_ID = PE.PE_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pPE_Performance' and type LIKE '%F%')
DROP FUNCTION [pPE_Performance]; 
GO
CREATE FUNCTION [pPE_Performance] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	PE.PE_ID, 
	PEDAT.PEDAT_PerformanceDate, 
	PEAUD.PEAUD_PerformanceAudience, 
	PEREV.PEREV_PerformanceRevenue
FROM 
	PE_Performance PE
LEFT JOIN 
	PEDAT_PerformanceDate PEDAT
ON 
	PEDAT.PE_ID = PE.PE_ID
LEFT JOIN 
	PEAUD_PerformanceAudience PEAUD
ON 
	PEAUD.PE_ID = PE.PE_ID
LEFT JOIN 
	PEREV_PerformanceRevenue PEREV
ON 
	PEREV.PE_ID = PE.PE_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dPE_Performance' and type LIKE '%F%')
DROP FUNCTION [dPE_Performance]; 
GO
CREATE FUNCTION [dPE_Performance] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	NULL as _inspectedDate, 
	PE.PE_ID, 
	PEDAT.PEDAT_PerformanceDate, 
	PEAUD.PEAUD_PerformanceAudience, 
	PEREV.PEREV_PerformanceRevenue
FROM 
	PE_Performance PE
LEFT JOIN 
	PEDAT_PerformanceDate PEDAT
ON 
	PEDAT.PE_ID = PE.PE_ID
LEFT JOIN 
	PEAUD_PerformanceAudience PEAUD
ON 
	PEAUD.PE_ID = PE.PE_ID
LEFT JOIN 
	PEREV_PerformanceRevenue PEREV
ON 
	PEREV.PE_ID = PE.PE_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'xPE_Performance' and type LIKE '%F%')
DROP FUNCTION [xPE_Performance]; 
GO
CREATE FUNCTION [xPE_Performance] (
	@intervalStart datetime, 
	@intervalEnd datetime, 
	@columns xml = '
	'
) 
RETURNS TABLE RETURN 
SELECT 
	NULL as _inspectedDate, 
	PE.PE_ID, 
	PEDAT.PEDAT_PerformanceDate, 
	PEAUD.PEAUD_PerformanceAudience, 
	PEREV.PEREV_PerformanceRevenue
FROM 
	PE_Performance PE
LEFT JOIN 
	PEDAT_PerformanceDate PEDAT
ON 
	PEDAT.PE_ID = PE.PE_ID
LEFT JOIN 
	PEAUD_PerformanceAudience PEAUD
ON 
	PEAUD.PE_ID = PE.PE_ID
LEFT JOIN 
	PEREV_PerformanceRevenue PEREV
ON 
	PEREV.PE_ID = PE.PE_ID;
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'ACAC_Actor_Actor_HasParents' and type LIKE '%U%')
CREATE TABLE [ACAC_Actor_Actor_HasParents] ( 
	AC_ID_1 int not null, 
	AC_ID_2 int not null, 
	PAR_ID bit not null, 
	_metadata int not null, 
	PRIMARY KEY (AC_ID_1 asc, AC_ID_2 asc, PAR_ID asc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lACAC_Actor_Actor_HasParents' and type LIKE '%V%')
DROP VIEW [lACAC_Actor_Actor_HasParents]; 
GO
CREATE VIEW [lACAC_Actor_Actor_HasParents] AS 
SELECT 
	ACAC.AC_ID_1, 
	ACAC.AC_ID_2, 
	PAR.PAR_Parenthood
FROM 
	ACAC_Actor_Actor_HasParents ACAC
LEFT JOIN 
	PAR_Parenthood PAR
ON 
	PAR.PAR_ID = ACAC.PAR_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pACAC_Actor_Actor_HasParents' and type LIKE '%F%')
DROP FUNCTION [pACAC_Actor_Actor_HasParents]; 
GO
CREATE FUNCTION [pACAC_Actor_Actor_HasParents] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	ACAC.AC_ID_1, 
	ACAC.AC_ID_2, 
	PAR.PAR_Parenthood
FROM 
	ACAC_Actor_Actor_HasParents ACAC
LEFT JOIN 
	PAR_Parenthood PAR
ON 
	PAR.PAR_ID = ACAC.PAR_ID;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dACAC_Actor_Actor_HasParents' and type LIKE '%F%')
DROP FUNCTION [dACAC_Actor_Actor_HasParents]; 
GO
CREATE FUNCTION [dACAC_Actor_Actor_HasParents] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	NULL as _inspectedDate, 
	ACAC.AC_ID_1, 
	ACAC.AC_ID_2, 
	PAR.PAR_Parenthood
FROM 
	ACAC_Actor_Actor_HasParents ACAC
LEFT JOIN 
	PAR_Parenthood PAR
ON 
	PAR.PAR_ID = ACAC.PAR_ID;
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PEAC_Performance_Actor_Cast' and type LIKE '%U%')
CREATE TABLE [PEAC_Performance_Actor_Cast] ( 
	PE_ID int not null, 
	AC_ID int not null, 
	_metadata int not null, 
	PRIMARY KEY (PE_ID asc, AC_ID asc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lPEAC_Performance_Actor_Cast' and type LIKE '%V%')
DROP VIEW [lPEAC_Performance_Actor_Cast]; 
GO
CREATE VIEW [lPEAC_Performance_Actor_Cast] AS 
SELECT 
	PEAC.PE_ID, 
	PEAC.AC_ID
FROM 
	PEAC_Performance_Actor_Cast PEAC;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pPEAC_Performance_Actor_Cast' and type LIKE '%F%')
DROP FUNCTION [pPEAC_Performance_Actor_Cast]; 
GO
CREATE FUNCTION [pPEAC_Performance_Actor_Cast] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	PEAC.PE_ID, 
	PEAC.AC_ID
FROM 
	PEAC_Performance_Actor_Cast PEAC;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dPEAC_Performance_Actor_Cast' and type LIKE '%F%')
DROP FUNCTION [dPEAC_Performance_Actor_Cast]; 
GO
CREATE FUNCTION [dPEAC_Performance_Actor_Cast] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	NULL as _inspectedDate, 
	PEAC.PE_ID, 
	PEAC.AC_ID
FROM 
	PEAC_Performance_Actor_Cast PEAC;
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PEPR_Performance_Program_ActedOut' and type LIKE '%U%')
CREATE TABLE [PEPR_Performance_Program_ActedOut] ( 
	PE_ID int not null, 
	PR_ID int not null, 
	_metadata int not null, 
	PRIMARY KEY (PE_ID asc, PR_ID asc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lPEPR_Performance_Program_ActedOut' and type LIKE '%V%')
DROP VIEW [lPEPR_Performance_Program_ActedOut]; 
GO
CREATE VIEW [lPEPR_Performance_Program_ActedOut] AS 
SELECT 
	PEPR.PE_ID, 
	PEPR.PR_ID
FROM 
	PEPR_Performance_Program_ActedOut PEPR;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pPEPR_Performance_Program_ActedOut' and type LIKE '%F%')
DROP FUNCTION [pPEPR_Performance_Program_ActedOut]; 
GO
CREATE FUNCTION [pPEPR_Performance_Program_ActedOut] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	PEPR.PE_ID, 
	PEPR.PR_ID
FROM 
	PEPR_Performance_Program_ActedOut PEPR;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dPEPR_Performance_Program_ActedOut' and type LIKE '%F%')
DROP FUNCTION [dPEPR_Performance_Program_ActedOut]; 
GO
CREATE FUNCTION [dPEPR_Performance_Program_ActedOut] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	NULL as _inspectedDate, 
	PEPR.PE_ID, 
	PEPR.PR_ID
FROM 
	PEPR_Performance_Program_ActedOut PEPR;
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'PEST_Performance_Stage_HeldAt' and type LIKE '%U%')
CREATE TABLE [PEST_Performance_Stage_HeldAt] ( 
	PE_ID int not null, 
	ST_ID int not null, 
	_metadata int not null, 
	PRIMARY KEY (PE_ID asc, ST_ID asc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lPEST_Performance_Stage_HeldAt' and type LIKE '%V%')
DROP VIEW [lPEST_Performance_Stage_HeldAt]; 
GO
CREATE VIEW [lPEST_Performance_Stage_HeldAt] AS 
SELECT 
	PEST.PE_ID, 
	PEST.ST_ID
FROM 
	PEST_Performance_Stage_HeldAt PEST;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pPEST_Performance_Stage_HeldAt' and type LIKE '%F%')
DROP FUNCTION [pPEST_Performance_Stage_HeldAt]; 
GO
CREATE FUNCTION [pPEST_Performance_Stage_HeldAt] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	PEST.PE_ID, 
	PEST.ST_ID
FROM 
	PEST_Performance_Stage_HeldAt PEST;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dPEST_Performance_Stage_HeldAt' and type LIKE '%F%')
DROP FUNCTION [dPEST_Performance_Stage_HeldAt]; 
GO
CREATE FUNCTION [dPEST_Performance_Stage_HeldAt] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	NULL as _inspectedDate, 
	PEST.PE_ID, 
	PEST.ST_ID
FROM 
	PEST_Performance_Stage_HeldAt PEST;
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'ACPR_Actor_Program_GotRating' and type LIKE '%U%')
CREATE TABLE [ACPR_Actor_Program_GotRating] ( 
	AC_ID int not null, 
	PR_ID int not null, 
	RAT_ID tinyint not null, 
	ACPR_FromDate datetime not null, 
	_metadata int not null, 
	PRIMARY KEY (AC_ID asc, PR_ID asc, ACPR_FromDate desc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lACPR_Actor_Program_GotRating' and type LIKE '%V%')
DROP VIEW [lACPR_Actor_Program_GotRating]; 
GO
CREATE VIEW [lACPR_Actor_Program_GotRating] AS 
SELECT 
	ACPR.AC_ID, 
	ACPR.PR_ID, 
	RAT.RAT_Rating, 
	ACPR.ACPR_FromDate
FROM 
	ACPR_Actor_Program_GotRating ACPR
LEFT JOIN 
	RAT_Rating RAT
ON 
	RAT.RAT_ID = ACPR.RAT_ID
WHERE 
	ACPR.ACPR_FromDate = (
		SELECT 
			max(sub.ACPR_FromDate) 
		FROM 
			ACPR_Actor_Program_GotRating sub 
		WHERE 
			sub.AC_ID = ACPR.AC_ID
		AND 
			sub.PR_ID = ACPR.PR_ID
	);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pACPR_Actor_Program_GotRating' and type LIKE '%F%')
DROP FUNCTION [pACPR_Actor_Program_GotRating]; 
GO
CREATE FUNCTION [pACPR_Actor_Program_GotRating] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	ACPR.AC_ID, 
	ACPR.PR_ID, 
	RAT.RAT_Rating, 
	ACPR.ACPR_FromDate
FROM 
	ACPR_Actor_Program_GotRating ACPR
LEFT JOIN 
	RAT_Rating RAT
ON 
	RAT.RAT_ID = ACPR.RAT_ID
WHERE 
	ACPR.ACPR_FromDate = (
		SELECT 
			max(sub.ACPR_FromDate) 
		FROM 
			ACPR_Actor_Program_GotRating sub 
		WHERE 
			sub.AC_ID = ACPR.AC_ID
		AND 
			sub.PR_ID = ACPR.PR_ID
		AND 
			sub.ACPR_FromDate <= @timepoint
	)
AND 
	RAT.RAT_Rating is not null;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dACPR_Actor_Program_GotRating' and type LIKE '%F%')
DROP FUNCTION [dACPR_Actor_Program_GotRating]; 
GO
CREATE FUNCTION [dACPR_Actor_Program_GotRating] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	ACPR.ACPR_FromDate as _inspectedDate, 
	ACPR.AC_ID, 
	ACPR.PR_ID, 
	RAT.RAT_Rating, 
	ACPR.ACPR_FromDate
FROM 
	ACPR_Actor_Program_GotRating ACPR
LEFT JOIN 
	RAT_Rating RAT
ON 
	RAT.RAT_ID = ACPR.RAT_ID
WHERE 
	ACPR.ACPR_FromDate between @intervalStart and @intervalEnd
AND 
	RAT.RAT_Rating is not null;
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE name = 'STPR_Stage_Program_IsPlaying' and type LIKE '%U%')
CREATE TABLE [STPR_Stage_Program_IsPlaying] ( 
	ST_ID int not null, 
	PR_ID int not null, 
	STPR_FromDate datetime not null, 
	_metadata int not null, 
	PRIMARY KEY (ST_ID asc, STPR_FromDate desc) 
);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'lSTPR_Stage_Program_IsPlaying' and type LIKE '%V%')
DROP VIEW [lSTPR_Stage_Program_IsPlaying]; 
GO
CREATE VIEW [lSTPR_Stage_Program_IsPlaying] AS 
SELECT 
	STPR.ST_ID, 
	STPR.PR_ID, 
	STPR.STPR_FromDate
FROM 
	STPR_Stage_Program_IsPlaying STPR
WHERE 
	STPR.STPR_FromDate = (
		SELECT 
			max(sub.STPR_FromDate) 
		FROM 
			STPR_Stage_Program_IsPlaying sub 
		WHERE 
			sub.ST_ID = STPR.ST_ID
	);
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'pSTPR_Stage_Program_IsPlaying' and type LIKE '%F%')
DROP FUNCTION [pSTPR_Stage_Program_IsPlaying]; 
GO
CREATE FUNCTION [pSTPR_Stage_Program_IsPlaying] (@timepoint datetime) 
RETURNS TABLE RETURN 
SELECT 
	STPR.ST_ID, 
	STPR.PR_ID, 
	STPR.STPR_FromDate
FROM 
	STPR_Stage_Program_IsPlaying STPR
WHERE 
	STPR.STPR_FromDate = (
		SELECT 
			max(sub.STPR_FromDate) 
		FROM 
			STPR_Stage_Program_IsPlaying sub 
		WHERE 
			sub.ST_ID = STPR.ST_ID
		AND 
			sub.STPR_FromDate <= @timepoint
	)
AND 
	STPR.PR_ID is not null;
GO
IF EXISTS (SELECT * FROM sys.objects WHERE name = 'dSTPR_Stage_Program_IsPlaying' and type LIKE '%F%')
DROP FUNCTION [dSTPR_Stage_Program_IsPlaying]; 
GO
CREATE FUNCTION [dSTPR_Stage_Program_IsPlaying] (@intervalStart datetime, @intervalEnd datetime) 
RETURNS TABLE RETURN 
SELECT 
	STPR.STPR_FromDate as _inspectedDate, 
	STPR.ST_ID, 
	STPR.PR_ID, 
	STPR.STPR_FromDate
FROM 
	STPR_Stage_Program_IsPlaying STPR
WHERE 
	STPR.STPR_FromDate between @intervalStart and @intervalEnd
AND 
	STPR.PR_ID is not null;
GO
